@@ -1,6 +1,6 @@
-package Pcore v0.13.4;
+package Pcore v0.14.0;
 
-use v5.22.0;
+use v5.22.1;
 use utf8;
 use strict;
 use warnings ( qw[all], FATAL => qw[utf8], NONFATAL => qw[] );
@@ -12,7 +12,9 @@ use if $^V ge 'v5.22', re      => 'strict';
 use if $^V ge 'v5.10', mro     => 'c3';
 no multidimensional;
 
-use namespace::clean qw[];
+use Sub::Util qw[];
+use Package::Stash qw[];
+
 use Const::Fast qw[];
 use Encode qw[];
 
@@ -32,6 +34,8 @@ use B::Hooks::EndOfScope::XS qw[];
 use EV;
 use AnyEvent;
 
+use Pcore::Core::Exporter qw[];
+
 # define global variables
 BEGIN {
     $Pcore::INITIALISED = 0;         # core initialisation flag
@@ -49,20 +53,22 @@ BEGIN {
         require Filter::Crypto::Decrypt if $ENV{PAR_TEMP};
     };
 
-    # define %EXPORT_PRAGMAS for exporter
-    %Pcore::EXPORT_PRAGMAS = (
+    # define alias for export
+    $Pcore::P = sub : const {'Pcore'};
+
+    # define %EXPORT_PRAGMA for exporter
+    $Pcore::EXPORT_PRAGMA = {
         autoload    => 0,    # export AUTOLOAD
         class       => 0,    # package is a Moo class
         config      => 0,    # mark package as perl config, used automatically during .perl config evaluation, do not use directly!!!
         const       => 0,    # export "const" keyword
         embedded    => 0,    # run in embedded mode
-        export      => 0,    # install standart import method
+        export      => 1,    # install standart import method
         inline      => 0,    # package use Inline
-        no_clean    => 0,    # do not perform namespace autoclean
         no_isa_attr => 0,    # do not check isa for class / role attributes
         role        => 0,    # package is a Moo role
         types       => 0,    # export types
-    );
+    };
 
     # configure standard library
     $Pcore::UTIL = {
@@ -77,6 +83,7 @@ BEGIN {
         geoip    => 'Pcore::Util::GeoIP',
         hash     => 'Pcore::Util::Hash',
         host     => 'Pcore::Util::URI::Host',
+        http     => 'Pcore::HTTP',
         list     => 'Pcore::Util::List',
         mail     => 'Pcore::Util::Mail',
         path     => 'Pcore::Util::Path',
@@ -89,14 +96,40 @@ BEGIN {
         term     => 'Pcore::Util::Term',
         text     => 'Pcore::Util::Text',
         tmpl     => 'Pcore::Util::Template',
-        ua       => 'Pcore::HTTP::UA',
         uri      => 'Pcore::Util::URI',
         uuid     => 'Pcore::Util::UUID',
     };
 }
 
-use Pcore::Core::Exporter qw[];
-use Pcore::Core::Autoload qw[];
+sub namespace_clean ($class) {
+    state $EXCEPT = {
+        import   => 1,
+        unimport => 1,
+        AUTOLOAD => 1,
+    };
+
+    my $stash = Package::Stash->new($class);
+
+    for my $subname ( $stash->list_all_symbols('CODE') ) {
+        my $fullname = Sub::Util::subname( $stash->get_symbol("&$subname") );
+
+        if ( "$class\::$subname" ne $fullname && !exists $EXCEPT->{$subname} && substr( $subname, 0, 1 ) ne q[(] ) {
+            my @symbols = map {
+                my $name = $_ . $subname;
+
+                my $def = $stash->get_symbol($name);
+
+                defined($def) ? [ $name, $def ] : ()
+            } '$', '@', '%', qw[];
+
+            $stash->remove_glob($subname);
+
+            $stash->add_symbol( $_->@* ) for @symbols;
+        }
+    }
+
+    return;
+}
 
 sub import {
     my $self = shift;
@@ -130,32 +163,23 @@ sub import {
     Const::Fast->import::into( $caller, 'const' ) if $pragma->{const};
 
     # export P sub to avoid indirect calls
+    # export i18n
     {
-        state $val;
-
-        if ( !$val ) {
-            $val = 'Pcore';
-
-            Internals::SvREADONLY( $val, 1 );
-        }
-
         no strict qw[refs];
 
-        my $symtab = \%{ $caller . q[::] };
+        *{"$caller\::P"} = $Pcore::P;
 
-        $symtab->{P} = \$val;
+        *{"$caller\::i18n"} = \&i18n;
 
         # flush the cache exactly once if we make any direct symbol table changes
         mro::method_changed_in($caller);
     }
 
-    # export Pcore::Core
+    # re-export core packages
     Pcore::Core::Const->import( -caller => $caller, $tags->@* );
     Pcore::Core::Dump->import( -caller => $caller, $tags->@* );
     Pcore::Core::Exception->import( -caller => $caller, $tags->@* );
     Pcore::Core::H->import( -caller => $caller, $tags->@* );
-    Pcore::Core::Log->import( -caller => $caller, $tags->@* );
-    Pcore::Core::I18N->import( -caller => $caller, $tags->@* );
 
     if ( !$pragma->{config} ) {
 
@@ -163,42 +187,49 @@ sub import {
         if ( $caller eq $Pcore::CALLER ) {
             B::Hooks::AtRuntime::at_runtime(
                 sub {
-                    Pcore->_CORE_RUN();
+                    Pcore::_CORE_RUN();
+
+                    return;
                 }
             );
         }
 
         # process -export pragma
-        Pcore::Core::Exporter->import( -caller => $caller ) if $pragma->{export};
+        if ( $pragma->{export} ) {
+            Pcore::Core::Exporter->import( -caller => $caller, -export => $pragma->{export} );
+        }
 
-        # process -autoload pragma
-        Pcore::Core::Autoload->import( -caller => $caller ) if $pragma->{autoload};
+        # process -autoload pragma, should be after the -role to support AUTOLOAD in Moo roles
+        if ( $pragma->{autoload} ) {
+            state $init = !!require Pcore::Core::Autoload;
+
+            Pcore::Core::Autoload->import( -caller => $caller );
+        }
 
         # process -inline pragma
-        require Pcore::Core::Inline if $pragma->{inline};
+        if ( $pragma->{inline} ) {
+            state $init = !!require Pcore::Core::Inline;
+        }
 
         # store significant pragmas for use in run-time
         $Pcore::EMBEDDED = 1 if $pragma->{embedded};
 
         $Pcore::NO_ISA_ATTR = 1 if $pragma->{no_isa_attr};
 
-        # CLI
-        if ( $pragma->{cli} ) {
-            push @Pcore::Core::CLI::PACKAGES, $caller;
-        }
-
         # re-export Moo
         if ( $pragma->{class} || $pragma->{role} ) {
 
             # install universal serializer methods
             B::Hooks::EndOfScope::XS::on_scope_end(
                 sub {
+                    namespace_clean($caller);
+
                     no strict qw[refs];
 
                     if ( my $ref = $caller->can('TO_DATA') ) {
-                        *{ $caller . '::TO_JSON' } = $ref unless $caller->can('TO_JSON');
+                        *{"$caller\::TO_JSON"} = $ref unless $caller->can('TO_JSON');
 
-                        *{ $caller . '::TO_CBOR' } = $ref unless $caller->can('TO_CBOR');
+                        *{"$caller\::TO_CBOR"} = $ref unless $caller->can('TO_CBOR');
                     }
 
                     return;
@@ -208,10 +239,10 @@ sub import {
             $pragma->{types} = 1;
 
             if ( $pragma->{class} ) {
-                $self->_import_moo( caller => $caller, class => 1 );
+                _import_moo( $caller, 0 );
             }
             elsif ( $pragma->{role} ) {
-                $self->_import_moo( caller => $caller, role => 1 );
+                _import_moo( $caller, 1 );
             }
 
             # reconfigure warnings, after Moo exported
@@ -220,62 +251,52 @@ sub import {
             warnings->import( 'experimental::autoderef', FATAL => qw[experimental::autoderef] ) if $^V lt 'v5.23';
 
             # apply default roles
-            # $self->_apply_roles( caller => $caller, roles => [qw[Pcore::Core::Autoload::Role]] );
+            # _apply_roles( $caller, qw[Pcore::Core::Autoload::Role] );
         }
 
         # export types
-        $self->_import_types( caller => $caller ) if $pragma->{types};
+        _import_types($caller) if $pragma->{types};
     }
 
-    # cleanup
-    namespace::clean->import( -cleanee => $caller, -except => [qw[import unimport AUTOLOAD]] ) unless $pragma->{no_clean};
-
     return;
 }
 
 sub unimport {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
-    my $self = shift;
+
+    # my $self = shift;
 
     # parse pragmas and tags
-    my ( $tags, $pragma ) = Pcore::Core::Exporter::parse_import( $self, @_ );
+    # my ( $tags, $pragma ) = Pcore::Core::Exporter::parse_import( $self, @_ );
 
     # find caller
-    my $caller = caller;
+    # my $caller = caller;
 
     # try to unimport Moo keywords
-    $self->_unimport_moo( caller => $caller );
+    # _unimport_moo($caller);
 
     # unimport types
-    $self->_unimport_types( caller => $caller );
+    # _unimport_types($caller);
 
     return;
 }
 
-sub _import_moo {
-    my $self = shift;
-    my %args = (
-        caller => undef,
-        class  => undef,
-        role   => undef,
-        @_,
-    );
-
-    if ( $args{class} ) {
-        Moo->import::into( $args{caller} );
+sub _import_moo ( $caller, $role ) {
+    if ($role) {
+        Moo::Role->import::into($caller);
     }
     else {
-        Moo::Role->import::into( $args{caller} );
+        Moo->import::into($caller);
     }
 
     # install "has" hook
     {
         no strict qw[refs];
 
-        my $has = *{ $args{caller} . '::has' }{CODE};
+        my $has = *{"$caller\::has"}{CODE};
 
         no warnings qw[redefine];
 
-        *{ $args{caller} . '::has' } = sub {
+        *{"$caller\::has"} = sub {
             my ( $name_proto, %spec ) = @_;
 
             # disable type checking
@@ -291,36 +312,20 @@ sub _import_moo {
     return;
 }
 
-sub _unimport_moo {
-    my $self = shift;
-    my %args = (
-        caller => undef,
-        @_,
-    );
-
-    if ( $Moo::MAKERS{ $args{caller} } && $Moo::MAKERS{ $args{caller} }->{is_class} ) {    # Moo class
-        Moo->unimport::out_of( $args{caller} );
+sub _unimport_moo ($caller) {
+    if ( $Moo::MAKERS{$caller} && $Moo::MAKERS{$caller}->{is_class} ) {    # Moo class
+        Moo->unimport::out_of($caller);
     }
-    elsif ( Moo::Role->is_role( $args{caller} ) ) {                                        # Moo::Role
-        Moo::Role->unimport::out_of( $args{caller} );
+    elsif ( Moo::Role->is_role($caller) ) {                                # Moo::Role
+        Moo::Role->unimport::out_of($caller);
     }
 
     return;
 }
 
-sub _import_types {
-    my $self = shift;
-    my %args = (
-        caller => undef,
-        @_,
-    );
-
-    state $required;
-
-    if ( !$required ) {
-        $required = 1;
-
-        local $ENV{PERL_TYPES_STANDARD_STRICTNUM} = 0;    # 0 - Num = LaxNum, 1 - Num = StrictNum
+sub _import_types ($caller) {
+    state $init = do {
+        local $ENV{PERL_TYPES_STANDARD_STRICTNUM} = 0;                     # 0 - Num = LaxNum, 1 - Num = StrictNum
 
         require Pcore::Core::Types;
         require Types::TypeTiny;
@@ -330,52 +335,41 @@ sub _import_types {
         # require Types::Common::String;
         # require Types::Encodings();
         # require Types::XSD::Lite();
-    }
 
-    Types::TypeTiny->import( { into => $args{caller} }, qw[StringLike HashLike ArrayLike CodeLike TypeTiny] );
+        1;
+    };
 
-    Types::Standard->import( { into => $args{caller} }, ':types' );
+    Types::TypeTiny->import( { into => $caller }, qw[StringLike HashLike ArrayLike CodeLike TypeTiny] );
 
-    Types::Common::Numeric->import( { into => $args{caller} }, ':types' );
+    Types::Standard->import( { into => $caller }, ':types' );
 
-    Pcore::Core::Types->import( { into => $args{caller} }, ':types' );
+    Types::Common::Numeric->import( { into => $caller }, ':types' );
+
+    Pcore::Core::Types->import( { into => $caller }, ':types' );
 
     return;
 }
 
-sub _unimport_types {
-    my $self = shift;
-    my %args = (
-        caller => undef,
-        @_,
-    );
+sub _unimport_types ($caller) {
+    Pcore::Core::Types->unimport( { into => $caller }, ':types' );
 
-    Pcore::Core::Types->unimport( { into => $args{caller} }, ':types' );
+    Types::Common::Numeric->unimport( { into => $caller }, ':types' );
 
-    Types::Common::Numeric->unimport( { into => $args{caller} }, ':types' );
+    Types::Standard->unimport( { into => $caller }, ':types' );
 
-    Types::Standard->unimport( { into => $args{caller} }, ':types' );
-
-    Types::TypeTiny->unimport( { into => $args{caller} }, qw[StringLike HashLike ArrayLike CodeLike TypeTiny] );
+    Types::TypeTiny->unimport( { into => $caller }, qw[StringLike HashLike ArrayLike CodeLike TypeTiny] );
 
     return;
 }
 
-sub _apply_roles {
-    my $self = shift;
-    my %args = (
-        caller => undef,
-        roles  => undef,
-        @_,
-    );
+sub _apply_roles ( $caller, @roles ) {
+    Moo::Role->apply_roles_to_package( $caller, @roles );
 
-    Moo::Role->apply_roles_to_package( $args{caller}, $args{roles}->@* );
-
-    if ( Moo::Role->is_role( $args{caller} ) ) {
-        Moo::Role->_maybe_reset_handlemoose( $args{caller} );    ## no critic qw[Subroutines::ProtectPrivateSubs]
+    if ( Moo::Role->is_role($caller) ) {
+        Moo::Role->_maybe_reset_handlemoose($caller);    ## no critic qw[Subroutines::ProtectPrivateSubs]
     }
     else {
-        Moo->_maybe_reset_handlemoose( $args{caller} );          ## no critic qw[Subroutines::ProtectPrivateSubs]
+        Moo->_maybe_reset_handlemoose($caller);          ## no critic qw[Subroutines::ProtectPrivateSubs]
     }
 
     return;
@@ -388,8 +382,6 @@ use Pcore::Core::Bootstrap qw[];
 use Pcore::Core::Dump qw[:CORE];
 use Pcore::Core::Exception qw[];
 use Pcore::Core::H qw[];
-use Pcore::Core::Log qw[:CORE];
-use Pcore::Core::I18N qw[:CORE];
 
 sub _CORE_INIT ($proc_cfg) {
 
@@ -465,9 +457,7 @@ sub _CORE_INIT ($proc_cfg) {
     $STDOUT_UTF8->autoflush(1);
     $STDERR_UTF8->autoflush(1);
 
-    Pcore::Core::Log::CORE_INIT();                                  # set default log pipes
     Pcore::Core::Exception::CORE_INIT();                            # set $SIG{__DIE__}, $SIG{__WARN__}, $SIG->{INT}, $SIG->{TERM} handlers
-    Pcore::Core::I18N::CORE_INIT();                                 # configure default I18N locations
 
     return;
 }
@@ -480,8 +470,7 @@ sub _CORE_RUN {
     # process will not daemonized;
 
     if ( !$Pcore::EMBEDDED ) {
-
-        require Pcore::Core::CLI;
+        state $init_cli = !!require Pcore::Core::CLI;
 
         Pcore::Core::CLI->new( { class => 'main' } )->run( \@ARGV );
 
@@ -491,16 +480,16 @@ sub _CORE_RUN {
         if ( !$MSWIN ) {
 
             # GID is inherited from UID by default
-            if ( defined $PROC->{UID} && !defined $PROC->{GID} ) {
-                my $uid = $PROC->{UID} =~ /\A\d+\z/sm ? $PROC->{UID} : getpwnam $PROC->{UID};
+            if ( defined $ENV->{UID} && !defined $ENV->{GID} ) {
+                my $uid = $ENV->{UID} =~ /\A\d+\z/sm ? $ENV->{UID} : getpwnam $ENV->{UID};
 
-                die qq[Can't find uid "$PROC->{UID}"] if !defined $uid;
+                die qq[Can't find uid "$ENV->{UID}"] if !defined $uid;
 
-                $PROC->{GID} = [ getpwuid $uid ]->[2];
+                $ENV->{GID} = [ getpwuid $uid ]->[2];
             }
 
             # change priv
-            Pcore->pm->change_priv( gid => $PROC->{GID}, uid => $PROC->{UID} );
+            Pcore->pm->change_priv( gid => $ENV->{GID}, uid => $ENV->{UID} );
         }
     }
 
@@ -509,53 +498,101 @@ sub _CORE_RUN {
 
 # AUTOLOAD
 sub AUTOLOAD ( $self, @ ) {    ## no critic qw[ClassHierarchies::ProhibitAutoloading]
-    my $method = our $AUTOLOAD =~ s/\A.*:://smr;
+    my $util = our $AUTOLOAD =~ s/\A.*:://smr;
 
-    die qq[Unregistered Pcore::Util "$method".] unless exists $Pcore::UTIL->{$method};
+    die qq[Unregistered Pcore::Util "$util".] unless my $class = $Pcore::UTIL->{$util};
 
-    my $class = $Pcore::UTIL->{$method};
+    require $class =~ s[::][/]smgr . '.pm';
 
-    require $class =~ s[::][/]smgr . q[.pm];
+    no strict qw[refs];
 
-    if ( $class->can('NEW') ) {
-        no strict qw[refs];
+    if ( $class->can('new') ) {
+        eval <<"PERL";         ## no critic qw[BuiltinFunctions::ProhibitStringyEval ErrorHandling::RequireCheckingReturnValueOfEval]
+            *{$util} = sub {
+                shift;
 
-        *{ $self . q[::] . $method } = \&{ $class . '::NEW' };
-
-        goto &{ $self . q[::] . $method };
+                return $class->new(\@_);
+            };
+PERL
     }
     else {
-        my $val = $Pcore::UTIL->{$method};
 
-        my $symtab;
+        # create util namespace with AUTOLOAD method
+        eval <<"PERL";         ## no critic qw[BuiltinFunctions::ProhibitStringyEval ErrorHandling::RequireCheckingReturnValueOfEval]
+            package $self\::Util::_$util;
 
-        # get symbol table ref
-        {
-            no strict qw[refs];
+            use Pcore;
 
-            $symtab = \%{ $self . q[::] };
-        }
+            sub AUTOLOAD {
+                my \$method = our \$AUTOLOAD =~ s/\\A.*:://smr;
 
-        # install method
-        $symtab->{$method} = sub : prototype() {$val};
+                no strict qw[refs];
 
-        mro::method_changed_in($self);
+                die qq[Sub "$class\::\$method" is not defined] if !defined &{"$class\::\$method"};
 
-        return $val;
+                # install method wrapper
+                eval <<"EVAL";
+                    *{"$self\::Util::_$util\::\$method"} = sub {
+                        shift;
+
+                        return &$class\::\$method;
+                    };
+EVAL
+
+                goto &{\$method};
+            }
+PERL
+
+        # create util namespace access method
+        *{$util} = sub : const {"$self\::Util::_$util"};
     }
+
+    goto &{$util};
 }
 
+# AE::cv
 sub cv {
     state $cv = AE::cv;
 
     return $cv;
 }
 
+# LOGGER
+sub log {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
+    state $log = do {
+        require Pcore::Core::Logger;
+
+        my $obj = Pcore::Core::Logger->new;
+
+        # set default log pipes
+        for my $ch ( $ENV->pcore->cfg->{log} ? $ENV->pcore->cfg->{log}->@* : (), $ENV->{CFG}->{log} ? $ENV->{CFG}->{log}->@* : () ) {
+            $obj->add_channel( $ch->@* );
+        }
+
+        $obj;
+    };
+
+    return $log;
+}
+
+# I18N
+sub i18n {
+    state $init = do {
+        require Pcore::Core::I18N;
+
+        Pcore::Core::I18N::CORE_INIT();    # configure default I18N locations
+
+        1;
+    };
+
+    return &Pcore::Core::I18N::i18n;       ## no critic qw[Subroutines::ProhibitAmpersandSigils]
+}
+
 # TODO add PerlIO::removeEsc layer
 sub _config_stdout ($h) {
     if ($MSWIN) {
-        if ( -t $h ) {    ## no critic qw[InputOutput::ProhibitInteractiveTest]
-            require Pcore::Core::PerlIOviaWinUniCon;
+        if ( -t $h ) {                     ## no critic qw[InputOutput::ProhibitInteractiveTest]
+            state $init = !!require Pcore::Core::PerlIOviaWinUniCon;
 
             binmode $h, ':raw:via(Pcore::Core::PerlIOviaWinUniCon)' or die;    # terminal
         }
@@ -582,21 +619,29 @@ sub _config_stdout ($h) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 46                   │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
+## │    3 │ 50                   │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 101                  │ Subroutines::ProhibitExcessComplexity - Subroutine "import" with high complexity score (29)                    │
+## │    3 │ 117                  │ BuiltinFunctions::ProhibitComplexMappings - Map blocks should have a single statement                          │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 166                  │ Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               │
+## │    3 │ 134                  │ Subroutines::ProhibitExcessComplexity - Subroutine "import" with high complexity score (26)                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 364                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_apply_roles' declared but not used │
+## │    3 │ 190                  │ Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 411, 440, 443, 447,  │ ErrorHandling::RequireCarping - "die" used instead of "croak"                                                  │
-## │      │ 497, 514, 560, 563,  │                                                                                                                │
-## │      │ 568, 571             │                                                                                                                │
+## │    3 │                      │ Subroutines::ProhibitUnusedPrivateSubroutines                                                                  │
+## │      │ 315                  │ * Private subroutine/method '_unimport_moo' declared but not used                                              │
+## │      │ 353                  │ * Private subroutine/method '_unimport_types' declared but not used                                            │
+## │      │ 365                  │ * Private subroutine/method '_apply_roles' declared but not used                                               │
+## │      │ 465                  │ * Private subroutine/method '_CORE_RUN' declared but not used                                                  │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 415                  │ InputOutput::RequireCheckedSyscalls - Return value of flagged function ignored - say                           │
+## │    3 │ 403, 432, 435, 439,  │ ErrorHandling::RequireCarping - "die" used instead of "croak"                                                  │
+## │      │ 486, 503, 597, 600,  │                                                                                                                │
+## │      │ 605, 608             │                                                                                                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 540                  │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
+## │    2 │ 123                  │ ValuesAndExpressions::ProhibitNoisyQuotes - Quotes used with a noisy string                                    │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    2 │ 127                  │ ControlStructures::ProhibitPostfixControls - Postfix control "for" used                                        │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    1 │ 407                  │ InputOutput::RequireCheckedSyscalls - Return value of flagged function ignored - say                           │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -617,7 +662,7 @@ Pcore - perl applications development environment
 
 =head1 SYNOPSIS
 
-    use Pcore qw[-<pragma> <import>], {config};
+    use Pcore -<pragma> qw[<import>], {config};
 
 =head1 DESCRIPTION
 
