@@ -1,11 +1,9 @@
 package Pcore::Handle::API::Google::Youtube;
 
-use Pcore qw[-role];
+use Pcore -role;
 
 with qw[Pcore::Handle::API::Google::_Role];
 
-no Pcore;
-
 1;
 __END__
 =pod
