@@ -1,10 +1,10 @@
 package Pcore::App::Role;
 
-use Pcore qw[-role];
+use Pcore -role;
 
 package Pcore::AppX::Role;
 
-use Pcore qw[-role];
+use Pcore -role;
 use Term::ANSIColor qw[:constants];
 
 has _appx_enum     => ( is => 'lazy', isa => ArrayRef, init_arg => undef );
@@ -104,8 +104,9 @@ around app_reset => sub ( $orig, $self ) {
 
 package Pcore::App;
 
-use Pcore qw[-class];
+use Pcore -class;
 use Pcore::AppX::HasAppX;
+use Pcore::Util::Text qw[to_camel_case];
 
 with qw[Pcore::App::Role];
 with qw[Pcore::AppX::Role];
@@ -202,11 +203,11 @@ sub BUILD ( $self, $args ) {
 
 # CFG
 sub _build_name_camel_case ($self) {
-    return P->text->to_camel_case( $self->name, ucfirst => 1 );
+    return to_camel_case( $self->name, ucfirst => 1 );
 }
 
 sub _build_app_dir ($self) {
-    my $dir = $PROC->{DATA_DIR} . $self->name . q[/];
+    my $dir = $ENV->{DATA_DIR} . $self->name . q[/];
 
     P->file->mkpath($dir);
 
