@@ -1,9 +1,10 @@
 package Pcore::Core::CLI;
 
-use Pcore qw[-class];
+use Pcore -class;
 use Getopt::Long qw[];
 use Pcore::Core::CLI::Opt;
 use Pcore::Core::CLI::Arg;
+use Config;
 
 has class => ( is => 'ro', isa => Str, required => 1 );
 has cmd_path => ( is => 'ro', isa => ArrayRef, default => sub { [] } );
@@ -15,9 +16,7 @@ has arg => ( is => 'lazy', isa => ArrayRef, init_arg => undef );
 has is_cmd     => ( is => 'lazy', isa => Bool,    init_arg => undef );
 has _cmd_index => ( is => 'lazy', isa => HashRef, init_arg => undef );
 
-no Pcore;
-
-my $SCAN_DEPS = !$PROC->is_par && $PROC->dist && $PROC->dist->cfg->{dist}->{par} && exists $PROC->dist->cfg->{dist}->{par}->{ $PROC->{SCRIPT_NAME} };
+my $SCAN_DEPS = !$ENV->is_par && $ENV->dist && $ENV->dist->cfg->{dist}->{par} && exists $ENV->dist->cfg->{dist}->{par}->{ $ENV->{SCRIPT_NAME} };
 
 sub _build_cmd ($self) {
     my $cmd = [];
@@ -384,7 +383,7 @@ sub _help_class_abstract ( $self, $class = undef ) {
 }
 
 sub _help_usage_string ($self) {
-    my $usage = join q[ ], P->path( $PROC->{SCRIPT_NAME} )->filename, $self->cmd_path->@*;
+    my $usage = join q[ ], P->path( $ENV->{SCRIPT_NAME} )->filename, $self->cmd_path->@*;
 
     if ( $self->is_cmd ) {
         $usage .= ' [COMMAND] [OPTION]...';
@@ -532,13 +531,20 @@ sub help_usage ( $self, $invalid_options = undef ) {
 }
 
 sub help_version ($self) {
-    my $format_info = sub ($dist) {
+    my $format_dist_info = sub ($dist) {
         return "@{[$dist->name]} @{[$dist->version]} @{[$dist->revision]} @{[$dist->build_date]}";
     };
 
-    say $format_info->( $PROC->dist ) if $PROC->dist;
+    if ( $ENV->dist ) {
+        say $format_dist_info->( $ENV->dist );
+    }
+    else {
+        say join q[ ], $ENV->{SCRIPT_NAME}, ( $main::VERSION ? version->new($main::VERSION)->normal : () );
+    }
 
-    say $format_info->( $PROC->pcore ) if !$PROC->dist || $PROC->dist->name ne $PROC->pcore->name;
+    say $format_dist_info->( $ENV->pcore ) if !$ENV->dist || $ENV->dist->name ne $ENV->pcore->name;
+
+    say 'Perl ' . $^V->normal . " $Config{archname}";
 
     exit 2;
 }
@@ -556,15 +562,15 @@ sub help_error ( $self, $msg ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 46                   │ ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         │
+## │    3 │ 45                   │ ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 89, 92, 157, 238,    │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## │      │ 273, 334, 357, 393,  │                                                                                                                │
-## │      │ 455, 460, 464, 473   │                                                                                                                │
+## │    3 │ 88, 91, 156, 237,    │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │      │ 272, 333, 356, 392,  │                                                                                                                │
+## │      │ 454, 459, 463, 472   │                                                                                                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 347                  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
+## │    3 │ 346                  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 493, 521             │ NamingConventions::ProhibitAmbiguousNames - Ambiguously named variable "abstract"                              │
+## │    3 │ 492, 520             │ NamingConventions::ProhibitAmbiguousNames - Ambiguously named variable "abstract"                              │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
