@@ -1,7 +1,7 @@
 package Pcore::Dist;
 
-use Pcore qw[-class];
-use Config qw[];
+use Pcore -class;
+use Config;
 
 has root => ( is => 'ro', isa => Maybe [Str], required => 1 );    # absolute path to the dist root
 has is_installed => ( is => 'ro', isa => Bool, required => 1 );   # dist is installed as CPAN module, root is undefined
@@ -11,7 +11,8 @@ has module => ( is => 'lazy', isa => InstanceOf ['Pcore::Util::Perl::Module'], p
 
 has build_info => ( is => 'lazy', isa => Maybe [HashRef], clearer => 1, init_arg => undef );
 has cfg => ( is => 'lazy', isa => HashRef, clearer => 1, init_arg => undef );
-has name => ( is => 'lazy', isa => Str, init_arg => undef );      # Dist-Name
+has name     => ( is => 'lazy', isa => Str,  init_arg => undef );    # Dist-Name
+has is_pcore => ( is => 'lazy', isa => Bool, init_arg => undef );
 
 has version    => ( is => 'lazy', isa => Object, clearer => 1, init_arg => undef );
 has revision   => ( is => 'lazy', isa => Str,    clearer => 1, init_arg => undef );
@@ -130,8 +131,6 @@ around new => sub ( $orig, $self, $dist ) {
     return;
 };
 
-no Pcore;
-
 # CLASS METHODS
 sub find_dist_root ( $self, $path ) {
     $path = P->path( $path, is_dir => 1 ) if !ref $path;
@@ -181,7 +180,7 @@ sub _build_module ($self) {
         $module = P->perl->module( $module_name, $self->root . 'lib/' );
     }
 
-    die qq[Disr main module "$module_name" wasn't found, distribution is corrupted] if !$module;
+    die qq[Distr main module "$module_name" wasn't found, distribution is corrupted] if !$module;
 
     return $module;
 }
@@ -198,6 +197,10 @@ sub _build_name ($self) {
     return $self->cfg->{dist}->{name};
 }
 
+sub _build_is_pcore ($self) {
+    return $self->name eq 'Pcore';
+}
+
 sub _build_version ($self) {
     if ( $self->is_installed ) {
         return version->new( $self->build_info->{version} );
@@ -279,9 +282,9 @@ sub clear ($self) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 106, 158             │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
+## │    3 │ 107, 157             │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 217                  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
+## │    2 │ 220                  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
