@@ -1,6 +1,6 @@
 package Pcore::Dist::Build;
 
-use Pcore qw[-class];
+use Pcore -class;
 use Pcore::Util::File::Tree;
 
 has dist => ( is => 'ro', isa => InstanceOf ['Pcore::Dist'] );
@@ -9,10 +9,8 @@ has user_cfg_path => ( is => 'lazy', isa => Str, init_arg => undef );
 has user_cfg => ( is => 'lazy', isa => Maybe [HashRef], init_arg => undef );
 has wiki => ( is => 'lazy', isa => Maybe [ InstanceOf ['Pcore::Dist::Build::Wiki'] ], init_arg => undef );
 
-no Pcore;
-
 sub _build_user_cfg_path ($self) {
-    return $PROC->{PCORE_USER_DIR} . 'pcore.ini';
+    return $ENV->{PCORE_USER_DIR} . 'pcore.ini';
 }
 
 sub _build_user_cfg ($self) {
@@ -24,7 +22,7 @@ sub _build_wiki ($self) {
 }
 
 sub create ( $self, @args ) {
-    require Pcore::Dist::Build::Create;
+    state $init = !!require Pcore::Dist::Build::Create;
 
     return Pcore::Dist::Build::Create->new( { @args, build => $self } )->run;    ## no critic qw[ValuesAndExpressions::ProhibitCommaSeparatedStatements]
 }
@@ -55,7 +53,7 @@ sub setup ($self) {
 }
 
 sub clean ($self) {
-    require Pcore::Dist::Build::Clean;
+    state $init = !!require Pcore::Dist::Build::Clean;
 
     Pcore::Dist::Build::Clean->new( { dist => $self->dist } )->run;
 
@@ -63,7 +61,7 @@ sub clean ($self) {
 }
 
 sub update ($self) {
-    require Pcore::Dist::Build::Update;
+    state $init = !!require Pcore::Dist::Build::Update;
 
     Pcore::Dist::Build::Update->new( { dist => $self->dist } )->run;
 
@@ -71,7 +69,7 @@ sub update ($self) {
 }
 
 sub deploy ( $self, %args ) {
-    require Pcore::Dist::Build::Deploy;
+    state $init = !!require Pcore::Dist::Build::Deploy;
 
     Pcore::Dist::Build::Deploy->new( { dist => $self->dist, %args } )->run;
 
@@ -87,7 +85,7 @@ sub test ( $self, @ ) {
         jobs    => 1,
         verbose => 0,
         keep    => 0,
-        @_[ 1 .. $#_ ],
+        splice @_, 1,
     );
 
     local $ENV{AUTHOR_TESTING}    = 1 if $args{author}  || $args{all};
@@ -115,7 +113,7 @@ sub test ( $self, @ ) {
 }
 
 sub release ( $self, @args ) {
-    require Pcore::Dist::Build::Release;
+    state $init = !!require Pcore::Dist::Build::Release;
 
     return Pcore::Dist::Build::Release->new( { dist => $self->dist, @args } )->run;
 }
@@ -126,10 +124,10 @@ sub par ( $self, @ ) {
         crypt   => undef,
         upx     => undef,
         clean   => undef,
-        @_[ 1 .. $#_ ],
+        splice @_, 1,
     );
 
-    require Pcore::Dist::Build::PAR;
+    state $init = !!require Pcore::Dist::Build::PAR;
 
     Pcore::Dist::Build::PAR->new( { %args, dist => $self->dist } )->run;    ## no critic qw[ValuesAndExpressions::ProhibitCommaSeparatedStatements]
 
@@ -137,7 +135,7 @@ sub par ( $self, @ ) {
 }
 
 sub temp_build ( $self, $keep = 0 ) {
-    require Pcore::Dist::Build::Temp;
+    state $init = !!require Pcore::Dist::Build::Temp;
 
     return Pcore::Dist::Build::Temp->new( { dist => $self->dist } )->run($keep);
 }
@@ -145,7 +143,7 @@ sub temp_build ( $self, $keep = 0 ) {
 sub tgz ($self) {
     my $temp = $self->temp_build;
 
-    require Archive::Tar;
+    state $init = !!require Archive::Tar;
 
     my $tgz = Archive::Tar->new;
 
@@ -171,7 +169,7 @@ sub tgz ($self) {
         }
     );
 
-    my $path = $PROC->{PCORE_SYS_DIR} . 'build/' . $self->dist->name . q[-] . $self->dist->version . '.tar.gz';
+    my $path = $ENV->{PCORE_SYS_DIR} . 'build/' . $self->dist->name . q[-] . $self->dist->version . '.tar.gz';
 
     $tgz->write( $path, Archive::Tar::COMPRESS_GZIP() );
 
