@@ -1,7 +1,7 @@
 package Pcore::Dist::Build::Deploy;
 
-use Pcore qw[-class];
-use Config qw[];
+use Pcore -class;
+use Config;
 
 has dist => ( is => 'ro', isa => InstanceOf ['Pcore::Dist'], required => 1 );
 
@@ -11,9 +11,13 @@ has recommends => ( is => 'ro', isa => Bool, default => 0 );
 has suggests   => ( is => 'ro', isa => Bool, default => 0 );
 has verbose    => ( is => 'ro', isa => Bool, default => 0 );
 
-# TODO under windows aqquire superuser automatically with use Win32::RunAsAdmin qw[force];
+# TODO under windows acquire superuser automatically with use Win32::RunAsAdmin qw[force];
 
-no Pcore;
+sub BUILDARGS ( $self, $args ) {
+    $args->{develop} = $args->{recommends} = $args->{suggests} = 1 if $args->{all};
+
+    return $args;
+}
 
 sub run ($self) {
     my $chdir_guard = P->file->chdir( $self->dist->root );
@@ -72,27 +76,26 @@ sub _chmod ($self) {
 
 sub _cpanm ($self) {
     if ( -f 'cpanfile' ) {
-        my $cfg = P->cfg->load( $PROC->res->get( '/data/pcore.perl', lib => 'pcore' ) );
+        my $cfg = P->cfg->load( $ENV->res->get( '/data/pcore.perl', lib => 'pcore' ) );
 
         # install known platform exceptions without tests
-        if ( exists $cfg->{cpanm}->{ $Config::Config{archname} } && $cfg->{cpanm}->{ $Config::Config{archname} }->@* ) {
-            P->sys->system( 'cpanm', '--notest', $cfg->{cpanm}->{ $Config::Config{archname} }->@* ) or return;
+        if ( exists $cfg->{cpan_notest}->{ $Config{archname} } && $cfg->{cpan_notest}->{ $Config{archname} }->@* ) {
+            P->sys->system( 'cpanm', '--notest', $cfg->{cpan_notest}->{ $Config{archname} }->@* ) or return;
         }
 
         my @args = (    #
             'cpanm',
-            '--with-feature', ( $^O =~ /MSWin/sm ? 'windows' : 'linux' ),
+            '--with-feature', ( $MSWIN ? 'windows' : 'linux' ),
             ( $self->develop    ? '--with-develop'    : () ),
             ( $self->recommends ? '--with-recommends' : () ),
             ( $self->suggests   ? '--with-suggests'   : () ),
             ( $self->verbose    ? '--verbose'         : () ),
-            '--cpanfile',    'cpanfile',
             '--installdeps', q[.],
         );
 
         say join q[ ], @args;
 
-        Pcore->sys->system(@args) or return;
+        P->sys->system(@args) or return;
     }
 
     return 1;
@@ -107,44 +110,44 @@ sub _install ($self) {
 
     my $canon_dist_root = P->path( $self->dist->root )->canonpath;
 
-    my $canon_bin_dir = $canon_dist_root . '/bin';
+    my $canon_bin_dir = "$canon_dist_root/bin";
 
     my $canon_dist_lib_dir = P->path("$canon_dist_root/../")->realpath->canonpath;
 
     if ($MSWIN) {
+        if ( $self->dist->is_pcore ) {
 
-        # set $ENV{PERL5LIB}
-        P->sys->system(qq[setx.exe /M PERL5LIB "$canon_dist_root/lib;"]) or return;
+            # set $ENV{PERL5LIB}
+            P->sys->system(qq[setx.exe /M PERL5LIB "$canon_dist_root/lib;"]) or return;
 
-        say qq[%PERL5LIB% updated];
+            say qq[%PERL5LIB% updated];
 
-        # set $ENV{PCORE_DIST_LIB}
-        P->sys->system(qq[setx.exe /M PCORE_DIST_LIB "$canon_dist_lib_dir"]) or return;
+            # set $ENV{PCORE_DIST_LIB}
+            P->sys->system(qq[setx.exe /M PCORE_DIST_LIB "$canon_dist_lib_dir"]) or return;
 
-        say qq[%PCORE_DIST_LIB% updated];
+            say qq[%PCORE_DIST_LIB% updated];
 
-        # set $ENV{PCORE_RES_LIB}
-        P->sys->system(qq[setx.exe /M PCORE_RES_LIB "$canon_dist_lib_dir/resources"]) or return;
+            # set $ENV{PCORE_RES_LIB}
+            P->sys->system(qq[setx.exe /M PCORE_RES_LIB "$canon_dist_lib_dir/resources"]) or return;
 
-        say qq[%PCORE_RES_LIB% updated];
+            say qq[%PCORE_RES_LIB% updated];
+        }
 
         # update $ENV{PATH}
-        require Win32::TieRegistry;
+        if ( -d $canon_bin_dir ) {
+            state $init = !!require Win32::TieRegistry;
 
-        my $system_path = Win32::TieRegistry->new('LMachine\SYSTEM\CurrentControlSet\Control\Session Manager\Environment')->GetValue('PATH');
+            my @system_path;
 
-        my $env_path = lc $system_path =~ s[/][\\]smgr;
+            for my $path ( grep { $_ && !/\A\h+\z/sm } split /$Config{path_sep}/sm, Win32::TieRegistry->new('LMachine\SYSTEM\CurrentControlSet\Control\Session Manager\Environment')->GetValue('PATH') ) {
+                my $normal_path = P->path( $path, is_dir => 1 );
 
-        $canon_bin_dir =~ s[/][\\]smg;
+                push @system_path, $path if $normal_path !~ m[\A\Q$canon_bin_dir\E/\z]sm;
+            }
 
-        my $bin_dir_lc = lc $canon_bin_dir;
+            push @system_path, $canon_bin_dir =~ s[/][\\]smgr;
 
-        if ( $env_path !~ m[\Q$bin_dir_lc\E(?:/|)(?:;|\Z)]sm ) {    # check if pcore bin dir is already in the path
-            my @path = grep { $_ && !/\A\h+\z/sm } split /;/sm, $system_path;    # remove empty path tokens, and tokens, consisting only from spaces
-
-            push @path, $canon_bin_dir;
-
-            $ENV{PATH} = join q[;], @path;                                       ## no critic qw[Variables::RequireLocalizedPunctuationVars]
+            $ENV{PATH} = join $Config{path_sep}, @system_path;    ## no critic qw[Variables::RequireLocalizedPunctuationVars]
 
             P->sys->system(qq[setx.exe /M PATH "$ENV{PATH};"]) or return;
 
@@ -152,16 +155,21 @@ sub _install ($self) {
         }
     }
     else {
-        my $data = <<"SH";
-export PERL5LIB="$canon_dist_root/lib:\$PERL5LIB"
+        my $data;
+
+        if ( $self->dist->is_pcore ) {
+            $data = <<"SH";
+if ! echo \$PERL5LIB | grep -Eq "(^|$Config{path_sep})$canon_dist_root/lib/?(\$|$Config{path_sep})" ; then export PERL5LIB="$canon_dist_root/lib$Config{path_sep}\$PERL5LIB" ; fi
 export PCORE_DIST_LIB="$canon_dist_lib_dir"
 export PCORE_RES_LIB="$canon_dist_lib_dir/resources"
-export PATH="\$PATH:$canon_bin_dir"
 SH
+        }
 
-        P->file->write_bin( '/etc/profile.d/pcore.sh', { mode => q[rw-r--r--] }, \$data );
+        $data .= qq[if ! echo \$PATH | grep -Eq "(^|$Config{path_sep})$canon_bin_dir/?(\$|$Config{path_sep})" ; then export PATH="\$PATH$Config{path_sep}$canon_bin_dir" ; fi\n] if -d $canon_bin_dir;
 
-        say '/etc/profile.d script installed';
+        P->file->write_bin( "/etc/profile.d/@{[lc $self->dist->name]}.sh", { mode => q[rw-r--r--] }, \$data );
+
+        say "/etc/profile.d/@{[lc $self->dist->name]}.sh installed";
     }
 
     return 1;
@@ -174,10 +182,10 @@ SH
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 103, 119, 124, 129,  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
-## │      │ 151                  │                                                                                                                │
+## │    3 │ 106, 123, 128, 133,  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
+## │      │ 154                  │                                                                                                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 134                  │ ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     │
+## │    1 │ 142                  │ ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
