@@ -1,46 +1,30 @@
 package Pcore::Dist::Build::PAR::Script;
 
-use Pcore qw[-class];
+use Pcore -class;
+use Pcore::Util::Text qw[format_num];
 use Pcore::Util::File::Tree;
 use Archive::Zip qw[];
 use PAR::Filter;
 use Filter::Crypto::CryptFile;
 use Pcore::Src::File;
+use Config;
 use Term::ANSIColor qw[:constants];
 
-has dist => ( is => 'ro', isa => InstanceOf ['Pcore::Dist'], required => 1 );
-has par_deps  => ( is => 'ro', isa => ArrayRef, required => 1 );
-has arch_deps => ( is => 'ro', isa => HashRef,  required => 1 );
+has dist   => ( is => 'ro', isa => InstanceOf ['Pcore::Dist'],       required => 1 );
 has script => ( is => 'ro', isa => InstanceOf ['Pcore::Util::Path'], required => 1 );
-has release     => ( is => 'ro', isa => Bool,    required => 1 );
-has crypt       => ( is => 'ro', isa => Bool,    required => 1 );
-has upx         => ( is => 'ro', isa => Bool,    required => 1 );
-has clean       => ( is => 'ro', isa => Bool,    required => 1 );
-has script_deps => ( is => 'ro', isa => HashRef, required => 1 );
-has resources => ( is => 'ro', isa => Maybe [ArrayRef] );
+has release => ( is => 'ro', isa => Bool, required => 1 );
+has crypt   => ( is => 'ro', isa => Bool, required => 1 );
+has upx     => ( is => 'ro', isa => Bool, required => 1 );
+has clean   => ( is => 'ro', isa => Bool, required => 1 );
+
+has mod      => ( is => 'ro', isa => ArrayRef, required => 1 );
+has resource => ( is => 'ro', isa => ArrayRef, required => 1 );
+has shlib    => ( is => 'ro', isa => ArrayRef, required => 1 );
 
 has tree => ( is => 'lazy', isa => InstanceOf ['Pcore::Util::File::Tree'], init_arg => undef );
 has par_suffix   => ( is => 'lazy', isa => Str, init_arg => undef );
 has exe_filename => ( is => 'lazy', isa => Str, init_arg => undef );
 
-no Pcore;
-
-our $PAR_DEPS = [    # common deps, will be included in any PAR
-
-    # following deps are needed to generate exception
-    'File/Path.pm',
-    'HTTP/Date.pm',
-    'Pcore/Core/H/Role.pm',
-    'Pcore/Core/H/Role/Wrapper.pm',
-    'Pcore/Handle/File.pm',
-    'Pcore/Util/Date.pm',
-    'Pcore/Util/Sys.pm',
-    'Time/Local.pm',
-    'Time/Moment.pm',
-    'Time/Zone.pm',
-    'bytes_heavy.pl',
-];
-
 sub _build_tree ($self) {
     return Pcore::Util::File::Tree->new;
 }
@@ -61,29 +45,13 @@ sub _build_exe_filename ($self) {
         push @attrs, 'devel';
     }
 
-    push @attrs, 'x64' if $Config::Config{archname} =~ /x64|x86_64/sm;
+    push @attrs, 'x64' if $Config{archname} =~ /x64|x86_64/sm;
 
     return $filename . q[-] . join( q[-], @attrs ) . $self->par_suffix;
 }
 
 sub run ($self) {
-    say BOLD . GREEN . qq[\nbuild] . ( $self->crypt ? ' crypted' : BOLD . RED . q[ not crypted] . BOLD . GREEN ) . qq[ "@{[$self->exe_filename]}" for $Config::Config{archname}] . RESET;
-
-    # add common par deps packages to the script_deps
-    for my $pkg ( $PAR_DEPS->@*, $self->par_deps->@* ) {
-        $self->script_deps->{$pkg} = 1;
-    }
-
-    # add known arch deps packages to the script_deps
-    for my $pkg ( $self->arch_deps->{pkg}->@* ) {
-        $self->script_deps->{$pkg} = 1;
-    }
-
-    # replace Inline.pm with Pcore/Core/Inline.pm
-    $self->script_deps->{'Pcore/Core/Inline.pm'} = 1 if delete $self->script_deps->{'Inline.pm'};
-
-    # add Filter::Crypto::Decrypt deps if crypt mode is used
-    $self->script_deps->{'Filter/Crypto/Decrypt.pm'} = 1 if $self->crypt;
+    say BOLD . GREEN . qq[\nbuild] . ( $self->crypt ? ' crypted' : BOLD . RED . q[ not crypted] . BOLD . GREEN ) . qq[ "@{[$self->exe_filename]}" for $Config{archname}] . RESET;
 
     # add main script
     $self->_add_perl_source( $self->script->realpath->to_string, 'script/main.pl' );
@@ -95,24 +63,25 @@ sub run ($self) {
     $self->tree->add_file( 'share/build.perl', $self->dist->create_build_info );
 
     # add Pcore dist.perl
-    $self->tree->add_file( 'lib/auto/share/dist/Pcore/dist.perl', $PROC->res->get_lib('pcore') . 'dist.perl' );
+    $self->tree->add_file( 'lib/auto/share/dist/Pcore/dist.perl', $ENV->res->get_lib('pcore') . 'dist.perl' );
 
     # add Pcore build.perl
-    $self->tree->add_file( 'lib/auto/share/dist/Pcore/build.perl', $PROC->pcore->create_build_info );
+    $self->tree->add_file( 'lib/auto/share/dist/Pcore/build.perl', $ENV->pcore->create_build_info );
 
     # add META.yml
     $self->tree->add_file( 'META.yml', P->data->to_yaml( { par => { clean => 1 } } ) ) if $self->clean;
 
-    # add shared libs
-    $self->_add_shared_libs;
+    # add shlib
+    $self->_add_shlib;
 
-    # process script deps
-    print 'adding deps ... ';
+    # add resources
+    $self->_add_resources;
+
+    # add modules
+    print 'adding modules ... ';
     $self->_add_modules;
     say 'done';
 
-    $self->_add_resources;
-
     my $temp = $self->tree->write_to_temp;
 
     # compress so with upx
@@ -125,7 +94,7 @@ sub run ($self) {
             sub ($path) {
 
                 # compress with upx
-                if ( $path =~ /\Q$Config::Config{so}\E\z/sm ) {
+                if ( $path =~ /\Q$Config{so}\E\z/sm ) {
                     push @compress_upx, $path->realpath;
                 }
 
@@ -171,16 +140,47 @@ sub run ($self) {
 
     P->file->chmod( 'r-x------', $target_exe );
 
-    say 'final binary size: ' . BOLD . GREEN . ( reverse join q[_], ( reverse -s $target_exe ) =~ /(\d{1,3})/smg ) . RESET . ' bytes';
+    say 'final binary size: ' . BOLD . GREEN . format_num( -s $target_exe ) . RESET . ' bytes';
+
+    return;
+}
+
+sub _add_shlib ($self) {
+    for my $shlib ( $self->shlib->@* ) {
+        my $found;
+
+        if ( -f $shlib ) {
+            $found = $shlib;
+        }
+        else {
+            # find in the $ENV{PATH}, @INC
+            for my $path ( split( /$Config{path_sep}/sm, $ENV{PATH} ), grep { !ref } @INC ) {
+                if ( -f "$path/$shlib" ) {
+                    $found = "$path/$shlib";
+
+                    last;
+                }
+            }
+        }
+
+        if ($found) {
+            my $filename = P->path($shlib)->filename;
+
+            say qq[shared lib added: "$filename"];
+
+            $self->tree->add_file( "shlib/$Config{archname}/$filename", $found );
+        }
+        else {
+            $self->_error(qq[shared object wasn't found: "$shlib"]);
+        }
+    }
 
     return;
 }
 
 sub _add_resources ($self) {
-    return if !$self->resources;
-
-    for my $res ( $self->resources->@* ) {
-        my $path = $PROC->res->get($res);
+    for my $res ( $self->resource->@* ) {
+        my $path = $ENV->res->get($res);
 
         if ( !$path ) {
             $self->_error(qq[required resource "$res" wasn't found]);
@@ -195,49 +195,30 @@ sub _add_resources ($self) {
     return;
 }
 
-sub _add_shared_libs ($self) {
-    my $processed_so;
-
-    for my $pkg ( keys $self->arch_deps->{so}->%* ) {
-        if ( exists $self->script_deps->{$pkg} ) {
-            for my $so ( $self->arch_deps->{so}->{$pkg}->@* ) {
-                next if exists $processed_so->{$so};
-
-                $processed_so->{$so} = 1;
-
-                my $so_filename = P->path($so)->filename;
-
-                my $found;
-
-                # find so in the $ENV{PATH}, @INC
-                for my $path ( split( /;/sm, $ENV{PATH} ), grep { !ref } @INC ) {
-                    if ( -f $path . q[/] . $so ) {
-                        $found = $path . q[/] . $so;
-
-                        last;
-                    }
-                }
-
-                if ($found) {
-                    say qq[shared lib added: "$so_filename"];
-
-                    $self->tree->add_file( 'shlib/' . $Config::Config{archname} . q[/] . $so_filename, $found );
-                }
-                else {
-                    $self->_error(qq[shared object wasn't found: "$so_filename"]);
-                }
-            }
-        }
-    }
-
-    return;
-}
-
 sub _add_modules ($self) {
-    for my $module ( grep {/[.](?:pl|pm)\z/sm} keys $self->script_deps->%* ) {
+
+    # add .pl, .pm
+    for my $module ( grep {/[.](?:pl|pm)\z/sm} $self->mod->@* ) {
         my $found = $self->_add_module($module);
 
-        $self->_error(qq[required deps wasn't found: $module]) if !$found && $self->script_deps->{$module} !~ /\A[(]eval\s/sm;
+        $self->_error(qq[required module wasn't found: "$module"]) if !$found;
+    }
+
+    # add .pc (part of some Win32API modules)
+    for my $module ( grep {/[.](?:pc)\z/sm} $self->mod->@* ) {
+        my $found;
+
+        for my $inc ( grep { !ref } @INC ) {
+            if ( -f "$inc/$module" ) {
+                $found = 1;
+
+                $self->tree->add_file( "$Config{version}/$Config{archname}/$module", "$inc/$module" );
+
+                last;
+            }
+        }
+
+        $self->_error(qq[required module wasn't found: "$module"]) if !$found;
     }
 
     return;
@@ -254,7 +235,7 @@ sub _add_module ( $self, $module ) {
     if ( my $auto_deps = $module->auto_deps ) {
 
         # module have auto deps
-        $target = $Config::Config{version} . q[/] . $Config::Config{archname} . q[/];
+        $target = $Config{version} . q[/] . $Config{archname} . q[/];
 
         for my $deps ( keys $auto_deps->%* ) {
             $self->tree->add_file( $target . $deps, $auto_deps->{$deps} );
@@ -388,13 +369,13 @@ sub _compress_upx ( $self, $path ) {
 
     my $upx;
 
-    my $upx_cache_dir = $PROC->{PCORE_USER_DIR} . 'upx-cache/';
+    my $upx_cache_dir = $ENV->{PCORE_USER_DIR} . 'upx-cache/';
 
     if ($MSWIN) {
-        $upx = $PROC->res->get('/bin/upx.exe');
+        $upx = $ENV->res->get('/bin/upx.exe');
     }
     else {
-        $upx = $PROC->res->get('/bin/upx_x64');
+        $upx = $ENV->res->get('/bin/upx_x64');
     }
 
     if ($upx) {
@@ -491,10 +472,10 @@ sub _repack_parl ( $self, $parl_path, $zip ) {
                 }
             )->run->out_buffer->$*;
         }
-        elsif ( $self->upx && $filename =~ /[.]$Config::Config{so}\z/sm ) {
+        elsif ( $self->upx && $filename =~ /[.]$Config{so}\z/sm ) {
 
             # store shared object to the temporary path
-            my $temppath = P->file->temppath( base => $parl_so_temp, suffix => $Config::Config{so} );
+            my $temppath = P->file->temppath( base => $parl_so_temp, suffix => $Config{so} );
 
             P->file->write_bin( $temppath, $content );
 
@@ -538,7 +519,7 @@ sub _repack_parl ( $self, $parl_path, $zip ) {
 
     my $out_len = $repacked_exe_fh->tell;
 
-    say 'parl repacked: ', BOLD . GREEN . q[-] . ( reverse join q[_], ( reverse( $out_len - $in_len ) ) =~ /(\d{1,3})/smg ) . RESET . ' bytes';
+    say 'parl repacked: ', BOLD . GREEN . format_num( $out_len - $in_len ) . RESET . ' bytes';
 
     # need to close fh before copy / patch file
     $repacked_exe_fh->close;
@@ -552,11 +533,11 @@ sub _repack_parl ( $self, $parl_path, $zip ) {
 
         print 'patch win exe icon ... ';
 
-        require Win32::Exe;
+        state $init = !!require Win32::Exe;
 
         my $exe = Win32::Exe->new( $repacked_exe_fh->path );
 
-        $exe->update( icon => $PROC->res->get('/data/par.ico') );
+        $exe->update( icon => $ENV->res->get('/data/par.ico') );
 
         say 'done';
     }
@@ -577,19 +558,19 @@ sub _error ( $self, $msg ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 201, 237, 259, 513   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 240, 494             │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 214, 410             │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
+## │    3 │ 254                  │ Subroutines::ProhibitManyArgs - Too many arguments                                                             │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 273                  │ Subroutines::ProhibitManyArgs - Too many arguments                                                             │
+## │    3 │ 391                  │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 448                  │ RegularExpressions::ProhibitCaptureWithoutTest - Capture variable used outside conditional                     │
+## │    3 │ 429                  │ RegularExpressions::ProhibitCaptureWithoutTest - Capture variable used outside conditional                     │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 483                  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
+## │    2 │ 464                  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 535, 537             │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
+## │    2 │ 516, 518             │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 470, 476, 541        │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
+## │    1 │ 451, 457             │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
