@@ -1,6 +1,7 @@
 package Pcore::Dist::Build::Release;
 
-use Pcore qw[-class];
+use Pcore -class;
+use Pcore::Util::Text qw[encode_utf8];
 use Pod::Markdown;
 use CPAN::Meta;
 
@@ -10,8 +11,6 @@ has major  => ( is => 'ro', isa => Bool, default => 0 );
 has minor  => ( is => 'ro', isa => Bool, default => 0 );
 has bugfix => ( is => 'ro', isa => Bool, default => 0 );
 
-no Pcore;
-
 sub run ($self) {
     if ( $self->dist->cfg->{dist}->{cpan} && !$self->dist->build->user_cfg || ( !$self->dist->build->user_cfg->{PAUSE}->{username} || !$self->dist->build->user_cfg->{PAUSE}->{password} ) ) {
         say 'You need to specify PAUSE credentials';
@@ -123,9 +122,9 @@ sub _upload_to_cpan ($self) {
 sub _upload ( $self, $username, $password, $path ) {
     my $body;
 
-    P->text->encode_utf8($username);
+    encode_utf8 $username;
 
-    P->text->encode_utf8($password);
+    encode_utf8 $password;
 
     $path = P->path($path);
 
@@ -169,7 +168,7 @@ sub _upload ( $self, $username, $password, $path ) {
 
     my $reason;
 
-    P->ua->post(
+    P->http->post(
         'https://pause.perl.org/pause/authenquery',
         headers => {
             AUTHORIZATION => 'Basic ' . P->data->to_b64_url( $username . q[:] . $password ) . q[==],
@@ -196,9 +195,9 @@ sub _upload ( $self, $username, $password, $path ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 31                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 30                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 16, 74, 105          │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
+## │    2 │ 15, 73, 104          │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
