@@ -1,17 +1,16 @@
 package Pcore::Dist::CLI::Deploy;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 with qw[Pcore::Dist::CLI];
 
-no Pcore;
-
 sub cli_abstract ($self) {
     return 'deploy distribution';
 }
 
 sub cli_opt ($self) {
     return {
+        all        => { desc => 'implies --develop, --recommends and --suggeests', },
         install    => { desc => 'install bin/ to PATH and lib/ to PERL5LIB', },
         develop    => { desc => 'cpanm --with-develop', },
         recommends => { desc => 'cpanm --with-recommends', },
@@ -39,7 +38,7 @@ sub run ( $self, $args ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 30                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 29                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
