@@ -1,6 +1,6 @@
 package Pcore::HTTP::Response;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::HTTP::Message];
 
@@ -12,8 +12,6 @@ has reason  => ( is => 'ro', isa => Str, writer => 'set_reason',  init_arg => un
 has is_http_redirect => ( is => 'ro', isa => Bool, writer => 'set_is_http_redirect', default => 0, init_arg => undef );
 has redirect => ( is => 'lazy', isa => ArrayRef, default => sub { [] }, init_arg => undef );
 
-no Pcore;
-
 1;
 __END__
 =pod
