@@ -1,20 +1,15 @@
 package Pcore::Util::PM;
 
-use Pcore;
+use Pcore -export, [qw[is_superuser run run_rpc]];
 use POSIX qw[];
 
 sub rename_process {
-    my $self = shift;
-
-    return 0 if *threads::tid{CODE} && threads->tid != 0;    # don't allow rename process from thread
-
-    $0 = shift;                                              ## no critic (Variables::RequireLocalizedPunctuationVars)
+    $0 = shift;    ## no critic (Variables::RequireLocalizedPunctuationVars)
 
     return 1;
 }
 
 sub change_priv {
-    my $self = shift;
     my %args = (
         gid => undef,
         uid => undef,
@@ -43,8 +38,6 @@ sub change_priv {
 }
 
 sub daemonize {
-    my $self = shift;
-
     state $daemonized = 0;
 
     return 0 if $daemonized;
@@ -71,35 +64,7 @@ sub daemonize {
     return 0;
 }
 
-sub is_process_alive {
-    my $self         = shift;
-    my $process_name = shift;
-
-    if ($MSWIN) {
-        return;
-    }
-    else {
-        require Proc::ProcessTable;
-
-        my $t = Proc::ProcessTable->new;
-
-        for ( $t->table->@* ) {
-            my $cmndline = $_->cmndline;
-
-            if ( ref $process_name eq 'Regexp' ) {
-                return $_->pid if ( defined $cmndline && $cmndline =~ /$process_name/sm && $_->pid != $$ );
-            }
-            else {
-                return $_->pid if ( defined $cmndline && $cmndline eq $process_name && $_->pid != $$ );
-            }
-        }
-        return 0;
-    }
-}
-
 sub is_superuser {
-    my $self = shift;
-
     if ($MSWIN) {
         return Win32::IsAdminUser();
     }
@@ -108,6 +73,39 @@ sub is_superuser {
     }
 }
 
+sub run (@) {
+    my %args = (
+        cmd      => undef,
+        std      => 0,
+        console  => 1,
+        blocking => 1,
+        on_ready => undef,
+        on_error => undef,
+        on_exit  => undef,
+        @_,
+    );
+
+    state $init = !!require Pcore::Util::PM::Proc;
+
+    return Pcore::Util::PM::Proc->new( \%args );
+}
+
+sub run_rpc ( $class, @ ) {
+    my %args = (
+        args     => {},
+        workers  => 0,
+        std      => 0,
+        console  => 1,
+        on_ready => undef,
+        splice( @_, 1 ),
+        class => $class,
+    );
+
+    state $init = !!require Pcore::Util::PM::RPC;
+
+    return Pcore::Util::PM::RPC->new( \%args );
+}
+
 1;
 __END__
 =pod
